==> vue-components-1.5.29.tgz: package/lib/drawer/src/Drawer.vue.rd.js <==
import { useInjectStyle as v } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as g, toRefs as S, openBlock as t, createBlock as u, unref as i, mergeProps as H, isRef as j, withCtx as f, createElementBlock as n, normalizeClass as a, createElementVNode as d, toDisplayString as m, createCommentVNode as r, renderSlot as B, createTextVNode as b } from "vue";
import { useVModel as D } from "@vueuse/core";
import N from "../../node_modules/ant-design-vue/es/drawer/index.rd.js";
import { drawerProps as T } from "./props.rd.js";
import $ from "../../node_modules/ant-design-vue/es/drawer/style/index.css.rd.js";
import "../../buttons/index.rd.js";
import c from "../../buttons/src/Button.vue.rd.js";
const A = { class: "flex flex-col justify-between" }, E = { class: "ml-auto h-full flex items-start justify-start" }, O = {
  key: 1,
  class: "border-t-gray-200 border-t-solid dark:border-t-slate-700 border-t pt-4 px-4 pb-4 flex absolute w-full bottom-0 justify-end mt-auto space-x-3"
}, q = /* @__PURE__ */ g({
  __name: "Drawer",
  props: T(),
  emits: ["update:visible"],
  setup(k, { emit: w }) {
    const o = k;
    v($, "ant-drawer");
    const { afterVisibleChange: l } = S(o), p = D(o, "visible");
    function y() {
      var e;
      w("update:visible", !1), (e = o.afterClose) == null || e.call(o);
    }
    const h = (...e) => {
      var s;
      (s = l == null ? void 0 : l.value) == null || s.call(l, ...e);
    };
    return (e, s) => (t(), u(i(N), H({
      visible: i(p),
      "onUpdate:visible": s[0] || (s[0] = (C) => j(p) ? p.value = C : null),
      title: null,
      footer: null,
      width: e.width,
      closable: !1,
      placement: e.placement,
      "wrap-style": e.wrapStyle,
      mask: e.mask,
      "mask-closable": e.maskClosable,
      "get-container": e.getContainer,
      style: { padding: "0px" },
      drawerStyle: { padding: "0px" },
      bodyStyle: { padding: "0px" }
    }, e.$attrs, {
      onClose: y,
      onAfterVisibleChange: h
    }), {
      default: f(() => [
        e.title || e.closable ? (t(), n("div", {
          key: 0,
          class: a([[
            e.headerClass,
            {
              "bg-gradient-to-br from-primary-700 dark:from-primary-800 to-primary-900": e.primaryHeader
            }
          ], "p-5 flex flex-row items-center"])
        }, [
          d("div", A, [
            e.title ? (t(), n("h2", {
              key: 0,
              class: a([[
                e.titleClass,
                {
                  "text-white": e.primaryHeader,
                  "text-theme": !e.primaryHeader
                }
              ], "mb-0 font-bold"])
            }, m(e.title), 3)) : r("", !0),
            d("p", {
              class: a([[e.descriptionClass, { "text-white": e.primaryHeader }], "mt-1 mb-0"])
            }, m(e.description), 3)
          ]),
          d("div", E, [
            e.closable ? (t(), n("span", {
              key: 0,
              class: a([[e.closeClass, { "!text-white text-white": e.primaryHeader }], "text-2xl text-slate-500 cursor-pointer hoverable-close hover:text-slate-700 dark:hover:text-slate-100 i-ic-round-close"]),
              onClick: y
            }, null, 2)) : r("", !0)
          ])
        ], 2)) : r("", !0),
        d("div", {
          style: { height: "500px" },
          class: a([[e.bodyClass], "pb-4 px-5 pt-0"])
        }, [
          B(e.$slots, "default")
        ], 2),
        e.showFooter ? (t(), n("div", O, [
          e.onCancel ? (t(), u(i(c), {
            key: 0,
            type: "border",
            color: "neutro",
            onClick: e.onCancel
          }, {
            default: f(() => [
              b(m(e.cancelText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : r("", !0),
          e.onOk ? (t(), u(i(c), {
            key: 1,
            color: "primary",
            onClick: e.onOk
          }, {
            default: f(() => [
              b(m(e.okText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : r("", !0)
        ])) : r("", !0)
      ]),
      _: 3
    }, 16, ["visible", "width", "placement", "wrap-style", "mask", "mask-closable", "get-container"]));
  }
});
export {
  q as default
};

==> vue-components-1.5.43.tgz: package/lib/drawer/src/Drawer.vue.rd.js <==
import { useInjectStyle as v } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as g, toRefs as H, openBlock as t, createBlock as u, unref as i, mergeProps as S, isRef as j, withCtx as f, createElementBlock as n, normalizeClass as a, createElementVNode as d, toDisplayString as m, createCommentVNode as r, renderSlot as B, createTextVNode as c } from "vue";
import { useVModel as D } from "@vueuse/core";
import N from "../../node_modules/ant-design-vue/es/drawer/index.rd.js";
import { drawerProps as T } from "./props.rd.js";
import $ from "../../node_modules/ant-design-vue/es/drawer/style/index.css.rd.js";
import "../../buttons/index.rd.js";
import b from "../../buttons/src/Button.vue.rd.js";
const z = { class: "flex flex-col justify-between" }, A = { class: "ml-auto h-full flex items-start justify-start" }, E = {
  key: 1,
  class: "border-t-gray-200 border-t-solid dark:border-t-slate-700 border-t pt-4 px-4 pb-4 flex absolute w-full bottom-0 justify-end mt-auto space-x-3"
}, q = /* @__PURE__ */ g({
  __name: "Drawer",
  props: T(),
  emits: ["update:visible"],
  setup(k, { emit: w }) {
    const o = k;
    v($, "ant-drawer");
    const { afterVisibleChange: l } = H(o), p = D(o, "visible");
    function y() {
      var e;
      w("update:visible", !1), (e = o.afterClose) == null || e.call(o);
    }
    const h = (...e) => {
      var s;
      (s = l == null ? void 0 : l.value) == null || s.call(l, ...e);
    };
    return (e, s) => (t(), u(i(N), S({
      visible: i(p),
      "onUpdate:visible": s[0] || (s[0] = (C) => j(p) ? p.value = C : null),
      title: null,
      footer: null,
      width: e.width,
      closable: !1,
      placement: e.placement,
      "wrap-style": e.wrapStyle,
      mask: e.mask,
      "mask-closable": e.maskClosable,
      "get-container": e.getContainer,
      style: { padding: "0px" },
      drawerStyle: { padding: "0px" },
      bodyStyle: { padding: "0px" }
    }, e.$attrs, {
      onClose: y,
      onAfterVisibleChange: h
    }), {
      default: f(() => [
        e.title || e.closable ? (t(), n("div", {
          key: 0,
          class: a([[
            e.headerClass,
            {
              "z-100 sticky top-0": e.stickyHeader,
              "bg-gradient-to-br from-primary-700 dark:from-primary-800 to-primary-900": e.primaryHeader
            }
          ], "p-5 flex flex-row items-center"])
        }, [
          d("div", z, [
            e.title ? (t(), n("h2", {
              key: 0,
              class: a([[
                e.titleClass,
                {
                  "text-white": e.primaryHeader,
                  "text-theme": !e.primaryHeader
                }
              ], "mb-0 font-bold"])
            }, m(e.title), 3)) : r("", !0),
            d("p", {
              class: a([[e.descriptionClass, { "text-white": e.primaryHeader }], "mt-1 mb-0"])
            }, m(e.description), 3)
          ]),
          d("div", A, [
            e.closable ? (t(), n("span", {
              key: 0,
              class: a([[e.closeClass, { "!text-white text-white": e.primaryHeader }], "text-2xl text-slate-500 cursor-pointer hoverable-close hover:text-slate-700 dark:hover:text-slate-100 i-ic-round-close"]),
              onClick: y
            }, null, 2)) : r("", !0)
          ])
        ], 2)) : r("", !0),
        d("div", {
          style: { height: "500px" },
          class: a([[e.bodyClass], "pb-4 px-5 pt-0"])
        }, [
          B(e.$slots, "default")
        ], 2),
        e.showFooter ? (t(), n("div", E, [
          e.onCancel ? (t(), u(i(b), {
            key: 0,
            type: "border",
            color: "neutro",
            onClick: e.onCancel
          }, {
            default: f(() => [
              c(m(e.cancelText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : r("", !0),
          e.onOk ? (t(), u(i(b), {
            key: 1,
            color: "primary",
            onClick: e.onOk
          }, {
            default: f(() => [
              c(m(e.okText), 1)
            ]),
            _: 1
          }, 8, ["onClick"])) : r("", !0)
        ])) : r("", !0)
      ]),
      _: 3
    }, 16, ["visible", "width", "placement", "wrap-style", "mask", "mask-closable", "get-container"]));
  }
});
export {
  q as default
};
